@@ -1,17 +1,18 @@
-/***************************************************************************
-    begin                : Sun May 15 2005
-    copyright            : (C) 2005, 2008 by Michael Pyne
-    email                : michael.pyne@kdemail.net
-***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/**
+ * Copyright (C) 2005, 2008 Michael Pyne <mpyne@kde.org>
+ *
+ * This program is free software; you can redistribute it and/or modify it under
+ * the terms of the GNU General Public License as published by the Free Software
+ * Foundation; either version 2 of the License, or (at your option) any later
+ * version.
+ *
+ * This program is distributed in the hope that it will be useful, but WITHOUT ANY
+ * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
+ * PARTICULAR PURPOSE. See the GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License along with
+ * this program.  If not, see <http://www.gnu.org/licenses/>.
+ */
 
 #include "covermanager.h"
 
@@ -97,7 +98,7 @@ QPixmap CoverData::thumbnail() const
  * different covers and such.  It holds the covers, and the map of path names
  * to cover ids, and has a few utility methods to load and save the data.
  *
- * @author Michael Pyne <michael.pyne@kdemail.net>
+ * @author Michael Pyne <mpyne@kde.org>
  * @see CoverManager
  */
 class CoverManagerPrivate
