@@ -1,17 +1,18 @@
-/***************************************************************************
-    begin                : Thu Aug 19 2004
-    copyright            : (C) 2002 - 2004 by Michael Pyne
-    email                : michael.pyne@kde.org
-***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/**
+ * Copyright (C) 2002-2004 Michael Pyne <mpyne@kde.org>
+ *
+ * This program is free software; you can redistribute it and/or modify it under
+ * the terms of the GNU General Public License as published by the Free Software
+ * Foundation; either version 2 of the License, or (at your option) any later
+ * version.
+ *
+ * This program is distributed in the hope that it will be useful, but WITHOUT ANY
+ * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
+ * PARTICULAR PURPOSE. See the GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License along with
+ * this program.  If not, see <http://www.gnu.org/licenses/>.
+ */
 
 #ifndef UPCOMINGPLAYLIST_H
 #define UPCOMINGPLAYLIST_H
@@ -37,7 +38,7 @@ class TrackSequenceManager;
  * it is added to the top of this playlist automatically, replacing any
  * currently playing song.
  *
- * @author Michael Pyne <michael.pyne@kdemail.net>
+ * @author Michael Pyne <mpyne@kde.org>
  * @see UpcomingSequenceIterator
  */
 class UpcomingPlaylist : public Playlist
@@ -134,7 +135,7 @@ private:
  *
  * @see UpcomingPlaylist
  * @see TrackSequenceManager
- * @author Michael Pyne <michael.pyne@kdemail.net>
+ * @author Michael Pyne <mpyne@kde.org>
  */
 class UpcomingPlaylist::UpcomingSequenceIterator : public TrackSequenceIterator
 {
